@@ -1,20 +1,19 @@
 arrange_expr_producer <- function(
-    data,
-    arrange_vars = NULL,
-    na_first = TRUE) {
-  if (!is.data.frame(data)) cli::cli_abort("{.arg data} must be a data.frame.")
-  if (isFALSE(is.character(arrange_vars) || (is.logical(arrange_vars) && rlang::is_named(arrange_vars)))) {
-    cli::cli_abort("{.arg arrange_vars} must be a character vector or a named logical vector.")
-  }
+  data,
+  arrange_vars = NULL,
+  na_first = TRUE
+) {
   if (is.null(arrange_vars)) {
     return(list(data = data, arrange_vars = list(NULL)))
   }
   if (is.character(arrange_vars)) {
     arrange_vars <- stats::setNames(rep(FALSE, times = length(arrange_vars)), nm = arrange_vars)
   }
+
+  # Check that arrange_vars exist in data
   check_arrange_vars <- names(arrange_vars)[!names(arrange_vars) %in% colnames(data)]
   if (length(check_arrange_vars) > 0) {
-    cli::cli_abort("{.arg arrange_vars} not found in {.arg data}: {check_arrange_vars}.")
+    cli::cli_abort("{.arg arrange_vars} not found in {.arg data}: {.var {check_arrange_vars}}.")
   }
 
 
@@ -43,13 +42,14 @@ arrange_expr_producer <- function(
     expr
   })
 
-  stats::setNames(arrange_exprs, arrange_vars)
+  stats::setNames(arrange_exprs, names(arrange_vars))
 }
 
 arrange2 <- function(
-    data,
-    arrange_vars = NULL,
-    na_first = TRUE) {
+  data,
+  arrange_vars = NULL,
+  na_first = TRUE
+) {
   if (is.null(arrange_vars)) {
     return(data)
   }
@@ -63,10 +63,14 @@ arrange2 <- function(
 }
 
 arrange_arrangers_and_groups <- function(
-    chapter_structure,
-    arrange_vars = NULL,
-    group_by_vars = NULL,
-    na_first = TRUE) {
+  chapter_structure,
+  arrange_vars = NULL,
+  group_by_vars = NULL,
+  na_first = TRUE
+) {
+  # Ungroup first to ensure arrange works globally, not within existing groups
+  chapter_structure <- dplyr::ungroup(chapter_structure)
+
   # Do same for arrange_vars and group_by_vars
   arrange_vars_expr <-
     arrange_expr_producer(
@@ -81,7 +85,8 @@ arrange_arrangers_and_groups <- function(
       na_first = na_first
     )
 
-  combined <- c(arrange_vars_expr)
+  # Combine arrange and group expressions, with arrange taking precedence
+  combined <- c(arrange_vars_expr, group_by_vars_expr)
   combined <- combined[!duplicated(names(combined))]
 
   data_sorted <- dplyr::arrange(chapter_structure, !!!combined)
