@@ -49,13 +49,15 @@
 #'
 #'   Column names used for identifying chapters and sections.
 #'
-#' @param arrange_section_by *Grouping columns*
+#' @param arrange_section_by *Sorting columns*
 #'
 #'   `vector<character>` or `named vector<logical>` // *default:* `NULL` (`optional`)
 #'
-#'   Column names used for sorting section within each organize_by group. If
-#'   character vector, will assume all are to be arranged in ascending order.
+#'   Column names used for sorting sections within each organize_by group. Can include
+#'   any column present in the output dataframe (both original and generated columns).
+#'   If character vector, will assume all are to be arranged in ascending order.
 #'   If a named logical vector, FALSE will indicate ascending, TRUE descending.
+#'   An error will be thrown if any specified column does not exist in the output.
 #'   Defaults to sorting in ascending order (alphabetical) for commonly needed
 #'   variable name/label info, and in descending order for chunk_templates as one
 #'   typically wants *u*nivariates before *b*ivariates.
@@ -186,7 +188,50 @@
 #'
 #'   Glue templates for the n_range columns to be created.
 #'
-#' @return Grouped tibble.
+#' @return
+#' A grouped tibble (data.frame) with columns that fall into two main categories:
+#'
+#' **Input columns (from user data):**
+#' - `chapter` (character): Chapter name (input)
+#' - `dep` (character): Dependent variable selector (input)
+#' - `indep` (character, optional): Independent variable selector (input)
+#'
+#' **Constructed columns (all start with a dot):**
+#' - `.variable_name`, `.variable_position` (character/integer): Variable name and position
+#' - `.variable_label`, `.variable_label_prefix`, `.variable_label_suffix` (character): Variable label and its components
+#' - `.variable_type`, `.variable_type_dep`, `.variable_type_indep` (character): Variable type(s)
+#' - `.variable_name_dep`, `.variable_name_indep` (character): Names of dependent/independent variables
+#' - `.variable_label_prefix_dep`, `.variable_label_prefix_indep` (character): Label prefixes for dep/indep
+#' - `.variable_group_dep` (character/factor): Grouping variable for bivariate analysis
+#' - `.variable_group_id` (integer): Numeric group identifier for bivariate analysis
+#' - `.chapter_number` (integer): Chapter number
+#' - `.template_name` (character): Name of chunk template used
+#' - `.obj_name`, `.chunk_name`, `.file_name` (character): Object, chunk, and file names (for output)
+#' - `.n`, `.n_range` (integer/character): Sample size and range
+#' - `.n_cats_dep`, `.n_cats_indep` (integer): Number of categories for dep/indep
+#' - `.max_chars_labels_dep`, `.max_chars_labels_indep` (integer): Max label length for dep/indep
+#' - `.max_chars_cats_dep`, `.max_chars_cats_indep` (integer): Max category label length for dep/indep
+#' - `.n_dep`, `.n_indep` (integer): Number of dep/indep variables in group
+#' - `.bi_test`, `.p_value` (character/numeric): Statistical test name and p-value for bivariates
+#' - `.keep_bi_rows` (logical): Whether bivariate row is kept
+#' - Other columns may be present depending on chunk templates and options.
+#'
+#' **Row count estimate:**
+#' - The number of rows in the output depends on the number of chapters,
+#'   dep/indep combinations, and chunk templates. Typically, it is the sum of
+#'   all unique variable combinations specified in `chapter_overview`, expanded
+#'   by chunk templates and filtered by significance and other options.
+#'   For a simple overview, expect one row per variable per chapter; for
+#'   bivariates, one row per dep-indep pair.
+#'
+#' **Grouping variables:**
+#' - The columns used for grouping (i.e., `dplyr::grouped_df`) are determined
+#'   by the `organize_by` argument. By default, this includes
+#'   `.chapter_number`, `.variable_label_prefix_dep`, `.variable_name_indep`,
+#'    and `.template_name`, but can be customized. These columns define how
+#'   the output is grouped for further analysis or reporting.
+#'
+#' See function source and documentation for details on each column's meaning and usage.
 #' @export
 #'
 #' @examples
@@ -209,15 +254,16 @@ refine_chapter_overview <-
            hide_variable_if_all_na = TRUE,
            keep_dep_indep_if_no_overlap = FALSE,
            organize_by = c(
-             "chapter",
+             ".chapter_number",
              ".variable_label_prefix_dep",
              ".variable_name_indep",
              ".template_name"
            ),
            arrange_section_by = c(
              .chapter_number = FALSE,
-             .variable_name_dep = FALSE,
-             .variable_name_indep = FALSE,
+             chapter = FALSE,
+             .variable_position_dep = FALSE,
+             .variable_position_indep = FALSE,
              .template_name = FALSE
            ),
            na_first_in_section = TRUE,
@@ -246,6 +292,13 @@ refine_chapter_overview <-
 
     # Things changed during validate_refine_chapter_overview_args should be set anew here:
     out <- args$chapter_overview
+    # Allow chapter to be factor, convert to character for downstream compatibility
+    if ("chapter" %in% names(out) && is.factor(out$chapter)) {
+      out$chapter <- as.character(out$chapter)
+    }
+    # Capture original chapter order for later reordering (GH #110)
+    original_chapter_order <- unique(out$chapter)
+
     chunk_templates <- args$chunk_templates
 
     if (is.null(data)) arrange_section_by <- NULL
@@ -278,12 +331,21 @@ refine_chapter_overview <-
     out <- remove_from_chapter_structure_if_all_na(
       chapter_structure = out,
       data = data,
-      hide_variable_if_all_na = hide_variable_if_all_na
+      hide_variable_if_all_na = hide_variable_if_all_na,
+      log_file = log_file
     )
 
     present_variable_names <-
       stringi::stri_remove_empty_na(unique(out$.variable_name))
 
+    if (length(present_variable_names) == 0) {
+      # No variables were selected from the provided chapter_overview selectors.
+      # This is almost always unintended (e.g. matches('non_existent_cols')).
+      cli::cli_abort(c("No variables were selected from {.arg chapter_overview$dep}.",
+        i = "This usually means the selector(s) do not match any columns in {.arg data}."
+      ))
+    }
+
     if (length(present_variable_names) > 0) {
       extended_info <-
         look_for_extended(
@@ -314,7 +376,8 @@ refine_chapter_overview <-
           data = data,
           hide_bi_entry_if_sig_above = hide_bi_entry_if_sig_above,
           always_show_bi_for_indep = always_show_bi_for_indep,
-          progress = progress
+          progress = progress,
+          log_file = log_file
         )
 
 
@@ -323,7 +386,7 @@ refine_chapter_overview <-
           chapter_structure = out,
           chunk_templates = chunk_templates
         )
-      out <- remove_from_chapter_structure_if_no_type_match(out)
+      out <- remove_from_chapter_structure_if_no_type_match(out, log_file = log_file)
 
       if (nrow(out) == 0) {
         return(out)
@@ -382,7 +445,8 @@ refine_chapter_overview <-
       remove_from_chapter_structure_if_n_below(
         chapter_structure = out,
         n_variable_name = ".n",
-        hide_chunk_if_n_below = hide_chunk_if_n_below
+        hide_chunk_if_n_below = hide_chunk_if_n_below,
+        log_file = log_file
       )
 
     out <-
@@ -431,7 +495,6 @@ refine_chapter_overview <-
       )
 
 
-
     out <-
       add_n_vars_to_chapter_structure(
         chapter_structure = out,
@@ -447,7 +510,6 @@ refine_chapter_overview <-
       )
 
 
-
     out <-
       add_obj_name_to_chapter_structure(
         chapter_structure = out,
@@ -482,7 +544,8 @@ refine_chapter_overview <-
       out <-
         remove_from_chapter_structure_if_no_overlap(
           chapter_structure = out, # Current
-          data = data
+          data = data,
+          log_file = log_file
         )
     }
 
@@ -495,5 +558,14 @@ refine_chapter_overview <-
 
     check_chapter_structure_for_duplicates(chapter_structure = out, organize_by = organize_by)
 
+    # Ensure chapter column is character before reordering and returning (GH #110)
+    if ("chapter" %in% names(out) && !is.character(out$chapter)) {
+      out$chapter <- as.character(out$chapter)
+    }
+    # Reorder output to match original chapter order (GH #110)
+    # Use stable sort to preserve within-chapter ordering
+    if ("chapter" %in% names(out) && length(original_chapter_order) > 1) {
+      out <- out[order(match(out$chapter, original_chapter_order), seq_len(nrow(out))), , drop = FALSE]
+    }
     out
   }
