@@ -4,6 +4,7 @@ remove_from_chapter_structure_if_non_significant <-
            hide_bi_entry_if_sig_above = .05,
            always_show_bi_for_indep = c(),
            progress = TRUE,
+           log_file = NULL,
            call = rlang::caller_env()) {
     check_data_frame(chapter_structure)
     check_data_frame(data)
@@ -35,8 +36,16 @@ remove_from_chapter_structure_if_non_significant <-
         out_bivariates <- dplyr::group_map(out_bivariates,
           .keep = TRUE,
           .f = function(df_col_row, df_col_key) {
-            df_col_row$.keep_indep <- FALSE
+            # Performance fix: skip test if indep is in always_show_bi_for_indep
+            if (!is.null(df_col_row$.variable_name_indep) &&
+              df_col_row$.variable_name_indep %in% always_show_bi_for_indep) {
+              df_col_row$.keep_indep <- TRUE
+              df_col_row$.bi_test <- NA_character_
+              df_col_row$.p_value <- NA_real_
+              return(df_col_row)
+            }
 
+            df_col_row$.keep_indep <- FALSE
 
             if (is.null(df_col_row$.variable_name_dep) ||
               length(df_col_row$.variable_name_dep) == 0 ||
@@ -56,13 +65,6 @@ remove_from_chapter_structure_if_non_significant <-
             }
 
 
-            count_uniques <- dplyr::count(df_chitest,
-              .data[[df_col_row$.variable_name_dep]],
-              .data[[df_col_row$.variable_name_indep]],
-              name = ".n_count"
-            )
-
-
             df_col_row$.keep_indep <-
               (dplyr::n_distinct(df_chitest[[df_col_row$.variable_name_dep]], na.rm = TRUE) > 1 ||
                 dplyr::n_distinct(df_chitest[[df_col_row$.variable_name_indep]], na.rm = TRUE) > 1) &&
@@ -87,7 +89,26 @@ remove_from_chapter_structure_if_non_significant <-
             out_bivariates$.p_value <= hide_bi_entry_if_sig_above) |
             (out_bivariates$.variable_name_indep %in% always_show_bi_for_indep)
 
-        # browser()
+        # Log removed bivariate entries
+        removed_bivariates <- out_bivariates[!out_bivariates$.keep_bi_rows, ]
+        if (nrow(removed_bivariates) > 0) {
+          removed_pairs <- paste0(
+            removed_bivariates$.variable_name_dep,
+            " \u00D7 ",
+            removed_bivariates$.variable_name_indep,
+            " (p=",
+            round(removed_bivariates$.p_value, 3),
+            ")"
+          )
+          cli::cli_inform("Hiding {nrow(removed_bivariates)} non-significant bivariate{?s} (p > {hide_bi_entry_if_sig_above}): {.var {cli::ansi_collapse(removed_pairs, trunc = 100)}}.")
+          if (is_string(log_file)) {
+            cat("\nHiding non-significant bivariate entries (p > ", hide_bi_entry_if_sig_above, "):\n", file = log_file, append = TRUE, sep = "")
+            cat(removed_pairs, sep = "; ", file = log_file, append = TRUE)
+            cat("\n", file = log_file, append = TRUE)
+          }
+        }
+
+
         out_bivariates <- vctrs::vec_slice(out_bivariates,
           out_bivariates$.keep_bi_rows,
           error_call = call
