@@ -6,12 +6,16 @@ validate_access_folder_paths <- function(remote_basepath,
                                                       "2023",
                                                       "Mesos"),
                                          warn = FALSE) {
+  if(!is.character(rel_path_base_to_parent_of_user_restricted_folder)) {
+    warnabort_fn("{.arg rel_path_base_to_parent_of_user_restricted_folder} must be a string.")
+  }
   rel_path_base_to_parent_of_user_restricted_folder <- file.path(local_basepath, rel_path_base_to_parent_of_user_restricted_folder)
   warnabort_fn <- if(isTRUE(warn)) cli::cli_warn else cli::cli_abort
-  for(path in c(remote_basepath, local_basepath, rel_path_base_to_parent_of_user_restricted_folder)) {
-    if(!rlang::is_string(path)) {
-      warnabort_fn("{.arg {path}} must be a string.")
-    }
+  if(!rlang::is_string(remote_basepath)) {
+    warnabort_fn("{.arg remote_basepath} must be a string.")
+  }
+  if(!rlang::is_string(local_basepath)) {
+    warnabort_fn("{.arg local_basepath} must be a string.")
   }
 }
 
