@@ -57,7 +57,6 @@ if (!exists(".saros.env")) .saros.env <- NULL
   )
 
 
-
   ################################################################################
   # for a single crowd only, no mesos
   .saros.env$default_chunk_templates_1 <<-
@@ -112,6 +111,49 @@ _{.variable_label_prefix_dep}_. `{{r}} x`.
 
 :::
 
+"
+    ) |>
+    tibble::add_row(
+      .template_name = "int_plot_html",
+      .template_variable_type_dep = "int;dbl",
+      .template_variable_type_indep = "fct;ord",
+      .template =
+        "
+::: {{#fig-{.chunk_name}}}
+
+```{{r}}
+{.obj_name} <- \n\tdata_{.chapter_foldername} |>\n\t\tmakeme(dep = c({.variable_name_dep}), \n\t\tindep = c({.variable_name_indep}), \n\t\ttype = 'int_plot_html')
+link <- make_link(data = {.obj_name}$data)
+link_plot <- make_link(data = {.obj_name}, \n\t\tfile_suffix = '.png', link_prefix='[PNG](', \n\t\tsave_fn = ggsaver)
+x <- I(paste0(c(link, link_plot), collapse=', '))
+girafe(ggobj = {.obj_name})
+```
+
+_{.variable_label_prefix_dep}_ by _{tolower(.variable_label_prefix_indep)}_. `{{r}} x`.
+
+:::
+
+"
+    ) |>
+    tibble::add_row(
+      .template_name = "int_table_html",
+      .template_variable_type_dep = "int;dbl",
+      .template_variable_type_indep = NA_character_,
+      .template =
+        "
+```{{r}}
+{.obj_name} <- \n\tdata_{.chapter_foldername} |>\n\t\tmakeme(dep = c({.variable_name_dep}), \n\t\ttype = 'int_table_html')
+link <- make_link(data = {.obj_name}$data)
+link_plot <- make_link(data = {.obj_name}, \n\t\tfile_suffix = '.png', link_prefix='[PNG](', \n\t\tsave_fn = ggsaver)
+x <- I(paste0(c(link, link_plot), collapse=', '))
+girafe(ggobj = {.obj_name})
+```
+
+_{.variable_label_prefix_dep}_. `{{r}} x`.
+
+:::
+
+
 "
     ) |>
     tibble::add_row(
@@ -223,12 +265,12 @@ _{.variable_label_prefix_dep}_.
 #| panel: tabset
 plots <- \n\tsaros::makeme(data = data_{.chapter_foldername}, \n\t\tdep = c({.variable_name_dep}), \n\t\tindep = c({.variable_name_indep}), \n\t\ttype='cat_plot_html', \n\t\tcrowd=c('target', 'others'), \n\t\tmesos_var = params$mesos_var, \n\t\tmesos_group = params$mesos_group)
 
-if(!all(sapply(plots, is.null))) {{
+if(!all(vapply(plots, is.null, logical(1)))) {{
 
   lapply(names(plots), function(.x) {{
     knitr::knit_child(text = c(
       '',
-      '\\newpage',
+      '#\\newpage',
       '',
       '##### `r .x`',
       '```{{r}}',
@@ -273,12 +315,12 @@ _{.variable_label_prefix_dep}_ by _{tolower(.variable_label_prefix_indep)}_.
 #| panel: tabset
 plots <- \n\tsaros::makeme(data = data_{.chapter_foldername}, \n\t\tdep = c({.variable_name_dep}), \n\t\ttype='cat_plot_html', \n\t\tcrowd=c('target', 'others'), \n\t\tmesos_var = params$mesos_var, \n\t\tmesos_group = params$mesos_group)
 
-if(!all(sapply(plots, is.null))) {{
+if(!all(vapply(plots, is.null, logical(1)))) {{
 
   lapply(names(plots), function(.x) {{
     knitr::knit_child(text = c(
       '',
-      '\\newpage',
+      '#\\newpage',
       '',
       '##### `r .x`',
       '',
@@ -309,6 +351,96 @@ _{.variable_label_prefix_dep}_.
 
 :::
 
+"
+    ) |>
+    tibble::add_row(
+      .template_name = "int_plot_html",
+      .template_variable_type_dep = "int;dbl",
+      .template_variable_type_indep = "fct;ord",
+      .template =
+        "
+::: {{#fig-{.chunk_name}}}
+
+```{{r}}
+#| output: asis
+#| panel: tabset
+plots <- \n\tsaros::makeme(data = data_{.chapter_foldername}, \n\t\tdep = c({.variable_name_dep}), \n\t\tindep = c({.variable_name_indep}), \n\t\ttype='int_plot_html', \n\t\tcrowd=c('target', 'others'), \n\t\tmesos_var = params$mesos_var, \n\t\tmesos_group = params$mesos_group)
+
+if(!all(vapply(plots, is.null, logical(1)))) {{
+
+  lapply(names(plots), function(.x) {{
+    knitr::knit_child(text = c(
+      '',
+      '#\\newpage',
+      '',
+      '##### `r .x`',
+      '',
+      '```{{r}}',
+      'library(ggplot2)',
+      'library(ggiraph)',
+      'link <- make_link(data = plots[[.x]]$data)',
+      'link_plot <- make_link(data = plots[[.x]], link_prefix=\\'[PNG](\\', file_suffix = \\'.png\\', save_fn = ggsaver)',
+      'x <- I(paste0(c(link, link_plot), collapse=\\', \\'))',
+      'girafe(ggobj = plots[[.x]])',
+      '```',
+      '',
+      '`r x`',
+      ''
+      ), envir = environment(), quiet = TRUE)
+  }}) |> unlist() |> cat(sep = '\\n')
+}}
+```
+
+_{.variable_label_prefix_dep}_ by _{tolower(.variable_label_prefix_indep)}_.
+
+:::
+
+
+"
+    ) |>
+    tibble::add_row(
+      .template_name = "int_plot_html",
+      .template_variable_type_dep = "int;dbl",
+      .template_variable_type_indep = NA_character_,
+      .template =
+        "
+::: {{#fig-{.chunk_name}}}
+
+```{{r}}
+#| output: asis
+#| panel: tabset
+plots <- \n\tsaros::makeme(data = data_{.chapter_foldername}, \n\t\tdep = c({.variable_name_dep}), \n\t\ttype='int_plot_html', \n\t\tcrowd=c('target', 'others'), \n\t\tmesos_var = params$mesos_var, \n\t\tmesos_group = params$mesos_group)
+
+if(!all(vapply(plots, is.null, logical(1)))) {{
+
+  lapply(names(plots), function(.x) {{
+    knitr::knit_child(text = c(
+      '',
+      '#\\newpage',
+      '',
+      '##### `r .x`',
+      '',
+      '```{{r}}',
+      'library(ggplot2)',
+      'library(ggiraph)',
+      'link <- make_link(data = plots[[.x]]$data)',
+      'link_plot <- make_link(data = plots[[.x]], link_prefix=\\'[PNG](\\', file_suffix = \\'.png\\', save_fn = ggsaver)',
+      'x <- I(paste0(c(link, link_plot), collapse=\\', \\'))',
+      'girafe(ggobj = plots[[.x]])',
+      '```',
+      '',
+      '`r x`',
+      ''
+      ), envir = environment(), quiet = TRUE)
+  }}) |> unlist() |> cat(sep = '\\n')
+}}
+```
+
+_{.variable_label_prefix_dep}_.
+
+:::
+
+
 "
     ) |>
     tibble::add_row(
@@ -323,12 +455,12 @@ _{.variable_label_prefix_dep}_.
 #| output: asis
 #| panel: tabset
 tbls <- \n\tsaros::makeme(data = data_{.chapter_foldername}, \n\t\tdep = c({.variable_name_dep}), \n\t\tindep = c({.variable_name_indep}), \n\t\ttype='cat_table_html', \n\t\tcrowd=c('target', 'others'), \n\t\tmesos_var = params$mesos_var, \n\t\tmesos_group = params$mesos_group)
-if(!all(sapply(tbls, is.null))) {{
+if(!all(vapply(tbls, is.null, logical(1)))) {{
 
 lapply(names(tbls), function(.x) {{
   knitr::knit_child(text = c(
       '',
-      '\\newpage',
+      '#\\newpage',
       '',
     '##### `r .x`',
     '',
@@ -367,12 +499,12 @@ _{.variable_label_prefix_dep}_.
 #| output: asis
 #| panel: tabset
 tbls <- \n\tsaros::makeme(data = data_{.chapter_foldername}, \n\t\tdep = c({.variable_name_dep}), \n\t\ttype='cat_table_html', \n\t\tcrowd=c('target', 'others'), \n\t\tmesos_var = params$mesos_var, \n\t\tmesos_group = params$mesos_group)
-if(!all(sapply(tbls, is.null))) {{
+if(!all(vapply(tbls, is.null, logical(1)))) {{
 
 lapply(names(tbls), function(.x) {{
   knitr::knit_child(text = c(
       '',
-      '\\newpage',
+      '#\\newpage',
       '',
     '##### `r .x`',
     '',
@@ -663,6 +795,236 @@ _{.variable_label_prefix_dep}_ for `{{r}} params$mesos_group`.
 :::
 
 
+"
+    )
+
+  ##################################################################################################################################
+  # For mesos using crowd_plots_as_tabset and txt_from_cat_mesos_plots
+  .saros.env$default_chunk_templates_4 <<-
+    data.frame(
+      .template_name = character(),
+      .template_variable_type_dep = character(),
+      .template_variable_type_indep = character(),
+      .template = character()
+    ) |>
+    tibble::add_row(
+      .template_name = "cat_plot_html",
+      .template_variable_type_dep = "fct;ord",
+      .template_variable_type_indep = "fct;ord",
+      .template =
+        "
+::: {{#fig-{.chunk_name}}}
+
+```{{r}}
+#| output: asis
+#| panel: tabset
+plots <- \n\tsaros::makeme(data = data_{.chapter_foldername}, \n\t\tdep = c({.variable_name_dep}), \n\t\tindep = c({.variable_name_indep}), \n\t\ttype='cat_plot_html', \n\t\tcrowd=c('target', 'others'), \n\t\tmesos_var = params$mesos_var, \n\t\tmesos_group = params$mesos_group)
+txts <- saros::txt_from_cat_mesos_plots(plots)
+saros::crowd_plots_as_tabset(plots, plot_type = 'cat_plot_html')
+```
+
+_{.variable_label_prefix_dep}_ by _{tolower(.variable_label_prefix_indep)}_.
+
+:::
+
+txts
+
+"
+    ) |>
+    tibble::add_row(
+      .template_name = "cat_plot_html",
+      .template_variable_type_dep = "fct;ord",
+      .template_variable_type_indep = NA_character_,
+      .template =
+        "
+::: {{#fig-{.chunk_name}}}
+
+```{{r}}
+#| output: asis
+#| panel: tabset
+plots <- \n\tsaros::makeme(data = data_{.chapter_foldername}, \n\t\tdep = c({.variable_name_dep}), \n\t\ttype='cat_plot_html', \n\t\tcrowd=c('target', 'others'), \n\t\tmesos_var = params$mesos_var, \n\t\tmesos_group = params$mesos_group)
+txts <- saros::txt_from_cat_mesos_plots(plots)
+saros::crowd_plots_as_tabset(plots, plot_type = 'cat_plot_html')
+```
+
+_{.variable_label_prefix_dep}_.
+
+:::
+
+txts
+
+"
+    ) |>
+    tibble::add_row(
+      .template_name = "int_plot_html",
+      .template_variable_type_dep = "int;dbl",
+      .template_variable_type_indep = "fct;ord",
+      .template =
+        "
+::: {{#fig-{.chunk_name}}}
+
+```{{r}}
+#| output: asis
+#| panel: tabset
+plots <- \n\tsaros::makeme(data = data_{.chapter_foldername}, \n\t\tdep = c({.variable_name_dep}), \n\t\tindep = c({.variable_name_indep}), \n\t\ttype='int_plot_html', \n\t\tcrowd=c('target', 'others'), \n\t\tmesos_var = params$mesos_var, \n\t\tmesos_group = params$mesos_group)
+
+saros::crowd_plots_as_tabset(plots, plot_type = 'int_plot_html')
+```
+
+_{.variable_label_prefix_dep}_ by _{tolower(.variable_label_prefix_indep)}_.
+
+:::
+
+
+"
+    ) |>
+    tibble::add_row(
+      .template_name = "int_plot_html",
+      .template_variable_type_dep = "int;dbl",
+      .template_variable_type_indep = NA_character_,
+      .template =
+        "
+::: {{#fig-{.chunk_name}}}
+
+```{{r}}
+#| output: asis
+#| panel: tabset
+plots <- \n\tsaros::makeme(data = data_{.chapter_foldername}, \n\t\tdep = c({.variable_name_dep}), \n\t\ttype='int_plot_html', \n\t\tcrowd=c('target', 'others'), \n\t\tmesos_var = params$mesos_var, \n\t\tmesos_group = params$mesos_group)
+saros::crowd_plots_as_tabset(plots, plot_type = 'int_plot_html')
+```
+
+_{.variable_label_prefix_dep}_.
+
+:::
+
+
+"
+    ) |>
+    tibble::add_row(
+      .template_name = "cat_table_html",
+      .template_variable_type_dep = "fct;ord",
+      .template_variable_type_indep = "fct;ord",
+      .template =
+        "
+::: {{#tbl-{.chunk_name}}}
+
+```{{r}}
+#| output: asis
+#| panel: tabset
+tbls <- \n\tsaros::makeme(data = data_{.chapter_foldername}, \n\t\tdep = c({.variable_name_dep}), \n\t\tindep = c({.variable_name_indep}), \n\t\ttype='cat_table_html', \n\t\tcrowd=c('target', 'others'), \n\t\tmesos_var = params$mesos_var, \n\t\tmesos_group = params$mesos_group)
+if(!all(vapply(tbls, is.null, logical(1)))) {{
+
+lapply(names(tbls), function(.x) {{
+  knitr::knit_child(text = c(
+      '',
+      '#\\newpage',
+      '',
+    '##### `r .x`',
+    '',
+    '```{{r}}',
+    'library(gt)',
+    'library(saros)',
+    'nrange <- stringi::stri_c(\\'N = \\', n_range(data = data_{.chapter_foldername}, \n\t\tdep = c({.variable_name_dep}), \n\t\tindep = c({.variable_name_indep})))',
+    'link <- make_link(data = tbls[[.x]])',
+    'x <- I(paste0(c(nrange, link), collapse=\\', \\')',
+    'gt(tbls[[.x]])',
+    '```',
+    '',
+    '`r x`',
+    ''
+    ), envir = environment(), quiet = TRUE)
+}}) |> unlist() |> cat(sep = '\\n')
+}}
+```
+
+_{.variable_label_prefix_dep}_ by _{tolower(.variable_label_prefix_indep)}_.
+
+:::
+
+
+"
+    ) |>
+    tibble::add_row(
+      .template_name = "cat_table_html",
+      .template_variable_type_dep = "fct;ord",
+      .template_variable_type_indep = NA_character_,
+      .template =
+        "
+::: {{#tbl-{.chunk_name}}}
+
+```{{r}}
+#| output: asis
+#| panel: tabset
+tbls <- \n\tsaros::makeme(data = data_{.chapter_foldername}, \n\t\tdep = c({.variable_name_dep}), \n\t\ttype='cat_table_html', \n\t\tcrowd=c('target', 'others'), \n\t\tmesos_var = params$mesos_var, \n\t\tmesos_group = params$mesos_group)
+if(!all(vapply(tbls, is.null, logical(1)))) {{
+
+  lapply(names(tbls), function(.x) {{
+    knitr::knit_child(text = c(
+        '',
+        '#\\newpage',
+        '',
+      '##### `r .x`',
+      '',
+      '```{{r}}',
+      'library(gt)',
+      'library(saros)',
+      'nrange <- stringi::stri_c(\\'N = \\', n_range(data = data_{.chapter_foldername}, \n\t\tdep = c({.variable_name_dep}), \n\t\tindep = c({.variable_name_indep})))',
+      'link <- make_link(data = tbls[[.x]])',
+      'x <- I(paste0(c(nrange, link), collapse=\\', \\')',
+      'gt(tbls[[.x]])',
+      '```',
+      '',
+      '`r x`',
+      ''
+      ), envir = environment(), quiet = TRUE)
+  }}) |> unlist() |> cat(sep = '\\n')
+}}
+```
+
+_{.variable_label_prefix_dep}_.
+
+:::
+
+
+"
+    ) |>
+    tibble::add_row(
+      .template_name = "chr_table",
+      .template_variable_type_dep = "chr",
+      .template_variable_type_indep = NA_character_,
+      .template =
+        "
+::: {{#tbl-{.chunk_name}}}
+
+```{{r}}
+#| output: asis
+tbl <- \n\tsaros::makeme(data = data_{.chapter_foldername}, \n\tdep = c({.variable_name_dep}), \n\ttype = 'chr_table_html', \n\tcrowd=c('target'),\n\thide_for_crowd_if_valid_n_below = 0,\n\thide_for_crowd_if_category_n_below = 0,\n\thide_for_crowd_if_cell_n_below = 0,\n\tmesos_var = params$mesos_var, \n\tmesos_group = params$mesos_group)
+if(!all(vapply(tbls, is.null, logical(1)))) {{
+
+  lapply(names(tbls), function(.x) {{
+    knitr::knit_child(text = c(
+        '',
+        '#\\newpage',
+        '',
+      '##### `r .x`',
+      '',
+      '```{{r}}',
+      'library(gt)',
+      'gt(tbls[[.x]])',
+      '```',
+      '',
+      '`r x`',
+      ''
+      ), envir = environment(), quiet = TRUE)
+  }}) |> unlist() |> cat(sep = '\\n')
+}}
+```
+
+_{.variable_label_prefix_dep}_.
+
+:::
+
+
 "
     )
 }
